@@ -127,6 +127,8 @@ void KTextToHTMLTest::testGetUrl2(const QString &left, const QString &right)
     schemas << QStringLiteral("sftp://");
     schemas << QStringLiteral("smb://");
     schemas << QStringLiteral("file://");
+    schemas << QStringLiteral("irc://");
+    schemas << QStringLiteral("ircs://");
 
     QStringList urls;
     urls << QStringLiteral("www.kde.org");
@@ -144,8 +146,8 @@ void KTextToHTMLTest::testGetUrl2(const QString &left, const QString &right)
     urls << QStringLiteral("user:pass@www.kde.org:1234/\nsub/path:with:colon/\nspecial(123)?\na=1#anchor[bla]");
     urls << QStringLiteral("user:pass@www.kde.org:1234/  \n  sub/path:with:colon/  \n\t   \t   special(123)?") + QStringLiteral("\n\t  \n\t   a=1#anchor[bla]");
 
-    for (const QString &schema : qAsConst(schemas)) {
-        for (QString url : qAsConst(urls)) {
+    for (const QString &schema : std::as_const(schemas)) {
+        for (QString url : std::as_const(urls)) {
             // by definition: if the URL is enclosed in brackets, the URL itself is not allowed
             // to contain the closing bracket, as this would be detected as the end of the URL
             if ((left.length() == 1) && (url.contains(right[0]))) {
@@ -189,8 +191,8 @@ void KTextToHTMLTest::testGetUrl2(const QString &left, const QString &right)
     QStringList starts;
     starts << QStringLiteral("www") << QStringLiteral("ftp") << QStringLiteral("news:www");
 
-    for (const QString &start : qAsConst(starts)) {
-        for (QString url : qAsConst(urlsWithoutSchema)) {
+    for (const QString &start : std::as_const(starts)) {
+        for (QString url : std::as_const(urlsWithoutSchema)) {
             // by definition: if the URL is enclosed in brackets, the URL itself is not allowed
             // to contain the closing bracket, as this would be detected as the end of the URL
             if ((left.length() == 1) && (url.contains(right[0]))) {
@@ -479,28 +481,4 @@ void KTextToHTMLTest::testHtmlConvert()
     QCOMPARE(actualHtml, htmlText);
 }
 
-void KTextToHTMLTest::benchHtmlConvert_data()
-{
-    QTest::addColumn<QString>("text");
-    QTest::addColumn<KTextToHTML::Options>("options");
-
-    auto text = QStringLiteral("foo bar asdf :)").repeated(1000);
-    QTest::newRow("plain") << text << KTextToHTML::Options();
-    QTest::newRow("preserve-spaces") << text << KTextToHTML::Options(KTextToHTML::PreserveSpaces);
-    QTest::newRow("highlight-text") << text << KTextToHTML::Options(KTextToHTML::HighlightText);
-    QTest::newRow("replace-smileys") << text << KTextToHTML::Options(KTextToHTML::ReplaceSmileys);
-    QTest::newRow("preserve-spaces+highlight-text") << text << KTextToHTML::Options(KTextToHTML::PreserveSpaces | KTextToHTML::HighlightText);
-    QTest::newRow("preserve-spaces+highlight-text+replace-smileys")
-        << text << KTextToHTML::Options(KTextToHTML::PreserveSpaces | KTextToHTML::HighlightText | KTextToHTML::ReplaceSmileys);
-}
-
-void KTextToHTMLTest::benchHtmlConvert()
-{
-    QFETCH(QString, text);
-    QFETCH(KTextToHTML::Options, options);
-
-    QBENCHMARK {
-        const QString html = KTextToHTML::convertToHtml(text, options);
-        Q_UNUSED(html);
-    }
-}
+#include "moc_ktexttohtmltest.cpp"
