@@ -18,9 +18,6 @@ private Q_SLOTS:
     void testHtmlConvert();
     void testHtmlConvert_data();
 
-    void benchHtmlConvert();
-    void benchHtmlConvert_data();
-
 private:
     void testGetUrl2(const QString &left, const QString &right);
 };
