@@ -47,11 +47,11 @@ KPluginFactory::Result<KPluginFactory> KPluginFactory::loadFactory(const KPlugin
         QPluginLoader loader(data.fileName());
         obj = loader.instance();
         if (!obj) {
-           result.errorString = tr("Could not load plugin from %1: %2").arg(data.fileName(), loader.errorString());
-           result.errorText = QStringLiteral("Could not load plugin from %1: %2").arg(data.fileName(), loader.errorString());
-           result.errorReason = INVALID_PLUGIN;
-           qCWarning(KCOREADDONS_DEBUG) << result.errorText;
-           return result;
+            result.errorString = tr("Could not load plugin from %1: %2").arg(data.fileName(), loader.errorString());
+            result.errorText = QStringLiteral("Could not load plugin from %1: %2").arg(data.fileName(), loader.errorString());
+            result.errorReason = INVALID_PLUGIN;
+            qCWarning(KCOREADDONS_DEBUG) << result.errorText;
+            return result;
         }
     }
 
@@ -279,3 +279,5 @@ QVariantList KPluginFactory::stringListToVariantList(const QStringList &list)
     }
     return variantlist;
 }
+
+#include "moc_kpluginfactory.cpp"
