@@ -128,8 +128,8 @@ public:
      * @since 5.91
      */
     enum KPluginMetaDataOption {
-        DoNotAllowEmptyMetaData, /// Plugins with empty metaData are considered invalid
-        AllowEmptyMetaData, /// Plugins with empty metaData are considered valid
+        DoNotAllowEmptyMetaData, ///< Plugins with empty metaData are considered invalid
+        AllowEmptyMetaData, ///< Plugins with empty metaData are considered valid
     };
 
     /** Creates an invalid KPluginMetaData instance */
@@ -617,18 +617,18 @@ public:
     bool isStaticPlugin() const;
 
 private:
-    QJsonObject rootObject() const;
+    KCOREADDONS_NO_EXPORT QJsonObject rootObject() const;
 #if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 92)
-    void loadFromDesktopFile(const QString &file, const QStringList &serviceTypes);
+    KCOREADDONS_NO_EXPORT void loadFromDesktopFile(const QString &file, const QStringList &serviceTypes);
 #endif
-    void loadFromJsonFile(const QString &file);
+    KCOREADDONS_NO_EXPORT void loadFromJsonFile(const QString &file);
 
 private:
-    QVariantList authorsVariant() const;
-    QVariantList translatorsVariant() const;
-    QVariantList otherContributorsVariant() const;
-    QStaticPlugin staticPlugin() const;
-    QString requestedFileName() const;
+    KCOREADDONS_NO_EXPORT QVariantList authorsVariant() const;
+    KCOREADDONS_NO_EXPORT QVariantList translatorsVariant() const;
+    KCOREADDONS_NO_EXPORT QVariantList otherContributorsVariant() const;
+    KCOREADDONS_NO_EXPORT QStaticPlugin staticPlugin() const;
+    KCOREADDONS_NO_EXPORT QString requestedFileName() const;
 
     QJsonObject m_metaData;
     QString m_fileName;
@@ -636,11 +636,7 @@ private:
     friend class KPluginFactory;
 };
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-inline size_t qHash(const KPluginMetaData &md, size_t seed)
-#else
 inline uint qHash(const KPluginMetaData &md, uint seed)
-#endif
 {
     return qHash(md.pluginId(), seed);
 }
