@@ -10,7 +10,6 @@
 #include "kmacroexpander_p.h"
 
 #include <QHash>
-#include <QStringList>
 
 KMacroExpanderBase::KMacroExpanderBase(QChar c)
     : d(new KMacroExpanderBasePrivate(c))
@@ -102,13 +101,11 @@ private:
     QHash<KT, VT> macromap;
 };
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 static QStringList &operator+=(QStringList &s, const QString &n)
 {
     s << n;
     return s;
 }
-#endif
 
 ////////
 
@@ -193,8 +190,9 @@ int KMacroMapExpander<QString, VT>::expandPlainMacro(const QString &str, int pos
         return 0;
     }
     int sl;
-    for (sl = 0; isIdentifier(str.unicode()[pos + sl].unicode()); sl++)
+    for (sl = 0; isIdentifier(str.unicode()[pos + sl].unicode()); sl++) {
         ;
+    }
     if (!sl) {
         return 0;
     }
@@ -217,7 +215,9 @@ int KMacroMapExpander<QString, VT>::expandEscapedMacro(const QString &str, int p
         ret += QString(escapeChar());
         return 2;
     }
-    int sl, rsl, rpos;
+    int sl;
+    int rsl;
+    int rpos;
     if (str.unicode()[pos + 1].unicode() == '{') {
         rpos = pos + 2;
         if ((sl = str.indexOf(QLatin1Char('}'), rpos)) < 0) {
@@ -227,8 +227,9 @@ int KMacroMapExpander<QString, VT>::expandEscapedMacro(const QString &str, int p
         rsl = sl + 3;
     } else {
         rpos = pos + 1;
-        for (sl = 0; isIdentifier(str.unicode()[rpos + sl].unicode()); ++sl)
+        for (sl = 0; isIdentifier(str.unicode()[rpos + sl].unicode()); ++sl) {
             ;
+        }
         rsl = sl + 1;
     }
     if (!sl) {
@@ -274,8 +275,9 @@ int KWordMacroExpander::expandPlainMacro(const QString &str, int pos, QStringLis
         return 0;
     }
     int sl;
-    for (sl = 0; isIdentifier(str.unicode()[pos + sl].unicode()); sl++)
+    for (sl = 0; isIdentifier(str.unicode()[pos + sl].unicode()); sl++) {
         ;
+    }
     if (!sl) {
         return 0;
     }
@@ -295,7 +297,9 @@ int KWordMacroExpander::expandEscapedMacro(const QString &str, int pos, QStringL
         ret += QString(escapeChar());
         return 2;
     }
-    int sl, rsl, rpos;
+    int sl;
+    int rsl;
+    int rpos;
     if (str.unicode()[pos + 1].unicode() == '{') {
         rpos = pos + 2;
         if ((sl = str.indexOf(QLatin1Char('}'), rpos)) < 0) {
@@ -305,8 +309,9 @@ int KWordMacroExpander::expandEscapedMacro(const QString &str, int pos, QStringL
         rsl = sl + 3;
     } else {
         rpos = pos + 1;
-        for (sl = 0; isIdentifier(str.unicode()[rpos + sl].unicode()); ++sl)
+        for (sl = 0; isIdentifier(str.unicode()[rpos + sl].unicode()); ++sl) {
             ;
+        }
         rsl = sl + 1;
     }
     if (!sl) {
