@@ -17,33 +17,31 @@
 #include <math.h>
 
 KFormatPrivate::KFormatPrivate(const QLocale &locale)
+    : m_locale(locale)
 {
-    m_locale = locale;
 }
 
 KFormatPrivate::~KFormatPrivate()
 {
 }
 
-constexpr double bpow(int exp) {
-    return (exp > 0) ? 2.0 * bpow(exp - 1) :
-        (exp < 0) ? 0.5 * bpow(exp + 1) :
-        1.0;
+constexpr double bpow(int exp)
+{
+    return (exp > 0) ? 2.0 * bpow(exp - 1) : (exp < 0) ? 0.5 * bpow(exp + 1) : 1.0;
 }
 
 QString KFormatPrivate::formatValue(double value,
-                        KFormat::Unit unit,
-                        QString unitString,
-                        int precision,
-                        KFormat::UnitPrefix prefix,
-                        KFormat::BinaryUnitDialect dialect) const
+                                    KFormat::Unit unit,
+                                    QString unitString,
+                                    int precision,
+                                    KFormat::UnitPrefix prefix,
+                                    KFormat::BinaryUnitDialect dialect) const
 {
     if (dialect <= KFormat::DefaultBinaryDialect || dialect > KFormat::LastBinaryDialect) {
         dialect = KFormat::IECBinaryDialect;
     }
 
-    if (static_cast<int>(prefix) < static_cast<int>(KFormat::UnitPrefix::Yocto) ||
-        static_cast<int>(prefix) > static_cast<int>(KFormat::UnitPrefix::Yotta)) {
+    if (static_cast<int>(prefix) < static_cast<int>(KFormat::UnitPrefix::Yocto) || static_cast<int>(prefix) > static_cast<int>(KFormat::UnitPrefix::Yotta)) {
         prefix = KFormat::UnitPrefix::AutoAdjust;
     }
 
@@ -52,8 +50,8 @@ QString KFormatPrivate::formatValue(double value,
         multiplier = 1000.0;
     }
 
-    int power = 0;
     if (prefix == KFormat::UnitPrefix::AutoAdjust) {
+        int power = 0;
         double adjustValue = qAbs(value);
         while (adjustValue >= multiplier) {
             adjustValue /= multiplier;
@@ -86,13 +84,11 @@ QString KFormatPrivate::formatValue(double value,
         prefix = map[power + 8];
     }
 
-    if (prefix == KFormat::UnitPrefix::Unity &&
-        unit == KFormat::Unit::Byte) {
+    if (prefix == KFormat::UnitPrefix::Unity && unit == KFormat::Unit::Byte) {
         precision = 0;
     }
 
-    struct PrefixMapEntry
-    {
+    struct PrefixMapEntry {
         KFormat::UnitPrefix prefix;
         double decimalFactor;
         double binaryFactor;
@@ -101,43 +97,44 @@ QString KFormatPrivate::formatValue(double value,
     };
 
     const PrefixMapEntry map[] = {
-        { KFormat::UnitPrefix::Yocto, 1e-24, bpow(-80), tr("y", "SI prefix for 10^⁻24"), QString() },
-        { KFormat::UnitPrefix::Zepto, 1e-21, bpow(-70), tr("z", "SI prefix for 10^⁻21"), QString() },
-        { KFormat::UnitPrefix::Atto,  1e-18, bpow(-60), tr("a", "SI prefix for 10^⁻18"), QString() },
-        { KFormat::UnitPrefix::Femto, 1e-15, bpow(-50), tr("f", "SI prefix for 10^⁻15"), QString() },
-        { KFormat::UnitPrefix::Pico,  1e-12, bpow(-40), tr("p", "SI prefix for 10^⁻12"), QString() },
-        { KFormat::UnitPrefix::Nano,  1e-9,  bpow(-30), tr("n", "SI prefix for 10^⁻9") , QString() },
-        { KFormat::UnitPrefix::Micro, 1e-6,  bpow(-20), tr("µ", "SI prefix for 10^⁻6") , QString() },
-        { KFormat::UnitPrefix::Milli, 1e-3,  bpow(-10), tr("m", "SI prefix for 10^⁻3") , QString() },
-        { KFormat::UnitPrefix::Unity, 1.0,   1.0      , QString()                      , QString() },
-        { KFormat::UnitPrefix::Kilo,  1e3,   bpow(10) , tr("k", "SI prefix for 10^3")  , tr("Ki", "IEC binary prefix for 2^10") },
-        { KFormat::UnitPrefix::Mega,  1e6,   bpow(20) , tr("M", "SI prefix for 10^6")  , tr("Mi", "IEC binary prefix for 2^20") },
-        { KFormat::UnitPrefix::Giga,  1e9,   bpow(30) , tr("G", "SI prefix for 10^9")  , tr("Gi", "IEC binary prefix for 2^30") },
-        { KFormat::UnitPrefix::Tera,  1e12,  bpow(40) , tr("T", "SI prefix for 10^12") , tr("Ti", "IEC binary prefix for 2^40") },
-        { KFormat::UnitPrefix::Peta,  1e15,  bpow(50) , tr("P", "SI prefix for 10^15") , tr("Pi", "IEC binary prefix for 2^50") },
-        { KFormat::UnitPrefix::Exa,   1e18,  bpow(60) , tr("E", "SI prefix for 10^18") , tr("Ei", "IEC binary prefix for 2^60") },
-        { KFormat::UnitPrefix::Zetta, 1e21,  bpow(70) , tr("Z", "SI prefix for 10^21") , tr("Zi", "IEC binary prefix for 2^70") },
-        { KFormat::UnitPrefix::Yotta, 1e24,  bpow(80) , tr("Y", "SI prefix for 10^24") , tr("Yi", "IEC binary prefix for 2^80") },
+        {KFormat::UnitPrefix::Yocto, 1e-24, bpow(-80), tr("y", "SI prefix for 10^⁻24"), QString()},
+        {KFormat::UnitPrefix::Zepto, 1e-21, bpow(-70), tr("z", "SI prefix for 10^⁻21"), QString()},
+        {KFormat::UnitPrefix::Atto, 1e-18, bpow(-60), tr("a", "SI prefix for 10^⁻18"), QString()},
+        {KFormat::UnitPrefix::Femto, 1e-15, bpow(-50), tr("f", "SI prefix for 10^⁻15"), QString()},
+        {KFormat::UnitPrefix::Pico, 1e-12, bpow(-40), tr("p", "SI prefix for 10^⁻12"), QString()},
+        {KFormat::UnitPrefix::Nano, 1e-9, bpow(-30), tr("n", "SI prefix for 10^⁻9"), QString()},
+        {KFormat::UnitPrefix::Micro, 1e-6, bpow(-20), tr("µ", "SI prefix for 10^⁻6"), QString()},
+        {KFormat::UnitPrefix::Milli, 1e-3, bpow(-10), tr("m", "SI prefix for 10^⁻3"), QString()},
+        {KFormat::UnitPrefix::Unity, 1.0, 1.0, QString(), QString()},
+        {KFormat::UnitPrefix::Kilo, 1e3, bpow(10), tr("k", "SI prefix for 10^3"), tr("Ki", "IEC binary prefix for 2^10")},
+        {KFormat::UnitPrefix::Mega, 1e6, bpow(20), tr("M", "SI prefix for 10^6"), tr("Mi", "IEC binary prefix for 2^20")},
+        {KFormat::UnitPrefix::Giga, 1e9, bpow(30), tr("G", "SI prefix for 10^9"), tr("Gi", "IEC binary prefix for 2^30")},
+        {KFormat::UnitPrefix::Tera, 1e12, bpow(40), tr("T", "SI prefix for 10^12"), tr("Ti", "IEC binary prefix for 2^40")},
+        {KFormat::UnitPrefix::Peta, 1e15, bpow(50), tr("P", "SI prefix for 10^15"), tr("Pi", "IEC binary prefix for 2^50")},
+        {KFormat::UnitPrefix::Exa, 1e18, bpow(60), tr("E", "SI prefix for 10^18"), tr("Ei", "IEC binary prefix for 2^60")},
+        {KFormat::UnitPrefix::Zetta, 1e21, bpow(70), tr("Z", "SI prefix for 10^21"), tr("Zi", "IEC binary prefix for 2^70")},
+        {KFormat::UnitPrefix::Yotta, 1e24, bpow(80), tr("Y", "SI prefix for 10^24"), tr("Yi", "IEC binary prefix for 2^80")},
     };
 
-    auto entry = std::find_if(std::begin(map), std::end(map),
-            [prefix](const PrefixMapEntry& e) { return e.prefix == prefix; });
+    auto entry = std::find_if(std::begin(map), std::end(map), [prefix](const PrefixMapEntry &e) {
+        return e.prefix == prefix;
+    });
 
     switch (unit) {
-        case KFormat::Unit::Bit:
-            unitString = tr("bit", "Symbol of binary digit");
-            break;
-        case KFormat::Unit::Byte:
-            unitString = tr("B", "Symbol of byte");
-            break;
-        case KFormat::Unit::Meter:
-            unitString = tr("m", "Symbol of meter");
-            break;
-        case KFormat::Unit::Hertz:
-            unitString = tr("Hz", "Symbol of hertz");
-            break;
-        case KFormat::Unit::Other:
-            break;
+    case KFormat::Unit::Bit:
+        unitString = tr("bit", "Symbol of binary digit");
+        break;
+    case KFormat::Unit::Byte:
+        unitString = tr("B", "Symbol of byte");
+        break;
+    case KFormat::Unit::Meter:
+        unitString = tr("m", "Symbol of meter");
+        break;
+    case KFormat::Unit::Hertz:
+        unitString = tr("Hz", "Symbol of hertz");
+        break;
+    case KFormat::Unit::Other:
+        break;
     }
 
     if (prefix == KFormat::UnitPrefix::Unity) {
@@ -165,8 +162,7 @@ QString KFormatPrivate::formatValue(double value,
     return tr("%1 %2%3", "MetricBinaryDialect").arg(numString, prefixString, unitString);
 }
 
-QString KFormatPrivate::formatByteSize(double size, int precision,
-                                       KFormat::BinaryUnitDialect dialect, KFormat::BinarySizeUnits units) const
+QString KFormatPrivate::formatByteSize(double size, int precision, KFormat::BinaryUnitDialect dialect, KFormat::BinarySizeUnits units) const
 {
     // Current KDE default is IECBinaryDialect
     if (dialect <= KFormat::DefaultBinaryDialect || dialect > KFormat::LastBinaryDialect) {
@@ -269,7 +265,7 @@ QString KFormatPrivate::formatByteSize(double size, int precision,
             //: JEDECBinaryDialect memory size in 10^80 bytes
             return tr("%1 YB", "JEDECBinaryDialect").arg(numString);
         }
-    } else {  // KFormat::IECBinaryDialect, KFormat::DefaultBinaryDialect
+    } else { // KFormat::IECBinaryDialect, KFormat::DefaultBinaryDialect
         switch (unit) {
         case KFormat::UnitByte:
             //: IECBinaryDialect size in bytes
@@ -310,18 +306,18 @@ enum TimeConstants {
     MSecsInDay = 86400000,
     MSecsInHour = 3600000,
     MSecsInMinute = 60000,
-    MSecsInSecond = 1000
+    MSecsInSecond = 1000,
 };
 
 QString KFormatPrivate::formatDuration(quint64 msecs, KFormat::DurationFormatOptions options) const
 {
     quint64 ms = msecs;
     if (options & KFormat::HideSeconds) {
-        //round to nearest minute
-        ms = qRound64(ms / (qreal)MSecsInMinute) * MSecsInMinute ;
+        // round to nearest minute
+        ms = qRound64(ms / (qreal)MSecsInMinute) * MSecsInMinute;
     } else if (!(options & KFormat::ShowMilliseconds)) {
-        //round to nearest second
-        ms = qRound64(ms / (qreal)MSecsInSecond) * MSecsInSecond ;
+        // round to nearest second
+        ms = qRound64(ms / (qreal)MSecsInSecond) * MSecsInSecond;
     }
 
     int hours = ms / MSecsInHour;
@@ -332,63 +328,48 @@ QString KFormatPrivate::formatDuration(quint64 msecs, KFormat::DurationFormatOpt
     ms = ms % MSecsInSecond;
 
     if ((options & KFormat::InitialDuration) == KFormat::InitialDuration) {
-
-        if ((options & KFormat::FoldHours) == KFormat::FoldHours
-                && (options & KFormat::ShowMilliseconds) == KFormat::ShowMilliseconds) {
+        if ((options & KFormat::FoldHours) == KFormat::FoldHours && (options & KFormat::ShowMilliseconds) == KFormat::ShowMilliseconds) {
             //: @item:intext Duration format minutes, seconds and milliseconds
-            return tr("%1m%2.%3s").arg(hours * 60 + minutes, 1, 10, QLatin1Char('0'))
-                   .arg(seconds, 2, 10, QLatin1Char('0'))
-                   .arg(ms, 3, 10, QLatin1Char('0'));
+            return tr("%1m%2.%3s").arg(hours * 60 + minutes, 1, 10, QLatin1Char('0')).arg(seconds, 2, 10, QLatin1Char('0')).arg(ms, 3, 10, QLatin1Char('0'));
         } else if ((options & KFormat::FoldHours) == KFormat::FoldHours) {
             //: @item:intext Duration format minutes and seconds
-            return tr("%1m%2s").arg(hours * 60 + minutes, 1, 10, QLatin1Char('0'))
-                   .arg(seconds, 2, 10, QLatin1Char('0'));
+            return tr("%1m%2s").arg(hours * 60 + minutes, 1, 10, QLatin1Char('0')).arg(seconds, 2, 10, QLatin1Char('0'));
         } else if ((options & KFormat::HideSeconds) == KFormat::HideSeconds) {
             //: @item:intext Duration format hours and minutes
-            return tr("%1h%2m").arg(hours, 1, 10, QLatin1Char('0'))
-                   .arg(minutes, 2, 10, QLatin1Char('0'));
+            return tr("%1h%2m").arg(hours, 1, 10, QLatin1Char('0')).arg(minutes, 2, 10, QLatin1Char('0'));
         } else if ((options & KFormat::ShowMilliseconds) == KFormat::ShowMilliseconds) {
             //: @item:intext Duration format hours, minutes, seconds, milliseconds
-            return tr("%1h%2m%3.%4s").arg(hours, 1, 10, QLatin1Char('0'))
-                   .arg(minutes, 2, 10, QLatin1Char('0'))
-                   .arg(seconds, 2, 10, QLatin1Char('0'))
-                   .arg(ms, 3, 10, QLatin1Char('0'));
+            return tr("%1h%2m%3.%4s")
+                .arg(hours, 1, 10, QLatin1Char('0'))
+                .arg(minutes, 2, 10, QLatin1Char('0'))
+                .arg(seconds, 2, 10, QLatin1Char('0'))
+                .arg(ms, 3, 10, QLatin1Char('0'));
         } else { // Default
             //: @item:intext Duration format hours, minutes, seconds
-            return tr("%1h%2m%3s").arg(hours, 1, 10, QLatin1Char('0'))
-                   .arg(minutes, 2, 10, QLatin1Char('0'))
-                   .arg(seconds, 2, 10, QLatin1Char('0'));
+            return tr("%1h%2m%3s").arg(hours, 1, 10, QLatin1Char('0')).arg(minutes, 2, 10, QLatin1Char('0')).arg(seconds, 2, 10, QLatin1Char('0'));
         }
 
     } else {
-
-        if ((options & KFormat::FoldHours) == KFormat::FoldHours
-                && (options & KFormat::ShowMilliseconds) == KFormat::ShowMilliseconds) {
+        if ((options & KFormat::FoldHours) == KFormat::FoldHours && (options & KFormat::ShowMilliseconds) == KFormat::ShowMilliseconds) {
             //: @item:intext Duration format minutes, seconds and milliseconds
-            return tr("%1:%2.%3").arg(hours * 60 + minutes, 1, 10, QLatin1Char('0'))
-                   .arg(seconds, 2, 10, QLatin1Char('0'))
-                   .arg(ms, 3, 10, QLatin1Char('0'));
+            return tr("%1:%2.%3").arg(hours * 60 + minutes, 1, 10, QLatin1Char('0')).arg(seconds, 2, 10, QLatin1Char('0')).arg(ms, 3, 10, QLatin1Char('0'));
         } else if ((options & KFormat::FoldHours) == KFormat::FoldHours) {
             //: @item:intext Duration format minutes and seconds
-            return tr("%1:%2").arg(hours * 60 + minutes, 1, 10, QLatin1Char('0'))
-                   .arg(seconds, 2, 10, QLatin1Char('0'));
+            return tr("%1:%2").arg(hours * 60 + minutes, 1, 10, QLatin1Char('0')).arg(seconds, 2, 10, QLatin1Char('0'));
         } else if ((options & KFormat::HideSeconds) == KFormat::HideSeconds) {
             //: @item:intext Duration format hours and minutes
-            return tr("%1:%2").arg(hours, 1, 10, QLatin1Char('0'))
-                   .arg(minutes, 2, 10, QLatin1Char('0'));
+            return tr("%1:%2").arg(hours, 1, 10, QLatin1Char('0')).arg(minutes, 2, 10, QLatin1Char('0'));
         } else if ((options & KFormat::ShowMilliseconds) == KFormat::ShowMilliseconds) {
             //: @item:intext Duration format hours, minutes, seconds, milliseconds
-            return tr("%1:%2:%3.%4").arg(hours, 1, 10, QLatin1Char('0'))
-                   .arg(minutes, 2, 10, QLatin1Char('0'))
-                   .arg(seconds, 2, 10, QLatin1Char('0'))
-                   .arg(ms, 3, 10, QLatin1Char('0'));
+            return tr("%1:%2:%3.%4")
+                .arg(hours, 1, 10, QLatin1Char('0'))
+                .arg(minutes, 2, 10, QLatin1Char('0'))
+                .arg(seconds, 2, 10, QLatin1Char('0'))
+                .arg(ms, 3, 10, QLatin1Char('0'));
         } else { // Default
             //: @item:intext Duration format hours, minutes, seconds
-            return tr("%1:%2:%3").arg(hours, 1, 10, QLatin1Char('0'))
-                   .arg(minutes, 2, 10, QLatin1Char('0'))
-                   .arg(seconds, 2, 10, QLatin1Char('0'));
+            return tr("%1:%2:%3").arg(hours, 1, 10, QLatin1Char('0')).arg(minutes, 2, 10, QLatin1Char('0')).arg(seconds, 2, 10, QLatin1Char('0'));
         }
-
     }
 
     Q_UNREACHABLE();
@@ -402,13 +383,13 @@ QString KFormatPrivate::formatDecimalDuration(quint64 msecs, int decimalPlaces)
         return tr("%1 days").arg(m_locale.toString(msecs / (MSecsInDay * 1.0), 'f', decimalPlaces));
     } else if (msecs >= MSecsInHour) {
         //: @item:intext %1 is a real number, e.g. 1.23 hours
-        return tr("%1 hours").arg(m_locale.toString(msecs / (MSecsInHour * 1.0), 'f',  decimalPlaces));
+        return tr("%1 hours").arg(m_locale.toString(msecs / (MSecsInHour * 1.0), 'f', decimalPlaces));
     } else if (msecs >= MSecsInMinute) {
         //: @item:intext %1 is a real number, e.g. 1.23 minutes
-        return tr("%1 minutes").arg(m_locale.toString(msecs / (MSecsInMinute * 1.0), 'f',  decimalPlaces));
+        return tr("%1 minutes").arg(m_locale.toString(msecs / (MSecsInMinute * 1.0), 'f', decimalPlaces));
     } else if (msecs >= MSecsInSecond) {
         //: @item:intext %1 is a real number, e.g. 1.23 seconds
-        return tr("%1 seconds").arg(m_locale.toString(msecs / (MSecsInSecond * 1.0), 'f',  decimalPlaces));
+        return tr("%1 seconds").arg(m_locale.toString(msecs / (MSecsInSecond * 1.0), 'f', decimalPlaces));
     }
     //: @item:intext %1 is a whole number
     //~ singular %n millisecond
@@ -420,7 +401,7 @@ enum DurationUnits {
     Days = 0,
     Hours,
     Minutes,
-    Seconds
+    Seconds,
 };
 
 static QString formatSingleDuration(DurationUnits units, int n)
@@ -520,22 +501,34 @@ QString KFormatPrivate::formatRelativeDate(const QDate &date, QLocale::FormatTyp
 QString KFormatPrivate::formatRelativeDateTime(const QDateTime &dateTime, QLocale::FormatType format) const
 {
     const QDateTime now = QDateTime::currentDateTime();
-    const qint64 daysTo = dateTime.daysTo(now);
-    if (daysTo > 2 || daysTo < -2) {
-        return m_locale.toString(dateTime, format);
-    }
 
     const auto secsToNow = dateTime.secsTo(now);
-    if (secsToNow >= 0 && secsToNow < 60 * 60) {
+    constexpr int secsInAHour = 60 * 60;
+    if (secsToNow >= 0 && secsToNow < secsInAHour) {
         const int minutesToNow = secsToNow / 60;
         if (minutesToNow <= 1) {
             return tr("Just now");
         } else {
-            return tr("%1 minutes ago").arg(minutesToNow);
+            //: @item:intext %1 is a whole number
+            //~ singular %n minute ago
+            //~ plural %n minutes ago
+            return tr("%n minute(s) ago", nullptr, minutesToNow);
         }
     }
 
-    /*: relative datetime with %1 result of formatReleativeDate() and %2 the formatted time
+    const auto timeFormatType = format == QLocale::FormatType::LongFormat ? QLocale::FormatType::ShortFormat : format;
+    const qint64 daysToNow = dateTime.daysTo(now);
+    QString dateString;
+    if (daysToNow < 2 && daysToNow > -2) {
+        dateString = formatRelativeDate(dateTime.date(), format);
+    } else {
+        dateString = m_locale.toString(dateTime.date(), format);
+    }
+
+    /*: relative datetime with %1 result of QLocale.toString(date, format) or formatRelativeDate
+        and %2 result of QLocale.toString(time, timeformatType)
         If this does not fit the grammar of your language please contact the i18n team to solve the problem */
-    return tr("%1, %2").arg(formatRelativeDate(dateTime.date(), format), m_locale.toString(dateTime.time(), format));
+    QString formattedDate = tr("%1 at %2").arg(dateString, m_locale.toString(dateTime.time(), timeFormatType));
+
+    return formattedDate.replace(0, 1, formattedDate.at(0).toUpper());
 }
