@@ -39,8 +39,5 @@ KProcessInfo KProcessList::processInfo(qint64 pid)
     auto testProcessIterator = std::find_if(processInfoList.begin(), processInfoList.end(), [pid](const KProcessList::KProcessInfo &info) {
         return info.pid() == pid;
     });
-    if (testProcessIterator != processInfoList.end()) {
-        return *testProcessIterator;
-    }
-    return KProcessInfo();
+    return testProcessIterator != processInfoList.end() ? *testProcessIterator : KProcessInfo{};
 }
